@@ -295,7 +295,7 @@ Dock.prototype = {
 
         this._installedChangedId = this._appSystem.connect('installed-changed', Lang.bind(this, this._queueRedisplay));
         this._appFavoritesChangedId = AppFavorites.getAppFavorites().connect('changed', Lang.bind(this, this._queueRedisplay));
-        this._appStateChangedId = this._tracker.connect('app-state-changed', Lang.bind(this, this._queueRedisplay));
+        this._appStateChangedId = this._appSystem.connect('app-state-changed', Lang.bind(this, this._queueRedisplay));
 
         this._overviewShowingId = Main.overview.connect('showing', Lang.bind(this, function() {
             this.actor.hide();
@@ -304,7 +304,6 @@ Dock.prototype = {
             this.actor.show();
         }));
         Main.layoutManager.addChrome(this.actor);
-        this.actor.lower_bottom();
 
         //hidden
         this._settings.connect('changed::'+DOCK_POSITION_KEY, Lang.bind(this, function (){
@@ -372,6 +371,8 @@ Dock.prototype = {
 
         this.actor.connect('leave-event', Lang.bind(this, this._hideDock));
         this.actor.connect('enter-event', Lang.bind(this, this._showDock));
+
+        this._hideDock();
     },
 
     destroy: function() {
@@ -386,7 +387,7 @@ Dock.prototype = {
         }
 
         if (this._appStateChangedId) {
-            this._tracker.disconnect(this._appStateChangedId);
+            this._appSystem.disconnect(this._appStateChangedId);
             this._appStateChangedId = 0;
         }
 
@@ -450,10 +451,7 @@ Dock.prototype = {
 
         let favorites = AppFavorites.getAppFavorites().getFavoriteMap();
 
-        /* hardcode here pending some design about how exactly desktop contexts behave */
-        let contextId = '';
-
-        let running = this._tracker.get_running_apps(contextId);
+        let running = this._appSystem.get_running();
         let runningIds = this._appIdListToHash(running);
 
         let icons = 0;
@@ -685,7 +683,7 @@ DockIcon.prototype = {
             this._menu.connect('activate-window', Lang.bind(this, function (menu, window) {
                 this.activateWindow(window);
             }));
-            this._menu.connect('popup', Lang.bind(this, function (menu, isPoppedUp) {
+            this._menu.connect('open-state-changed', Lang.bind(this, function (menu, isPoppedUp) {
                 if (!isPoppedUp){
                     //Restore value of autohidedock
                     this._dock._restoreHideDock();
@@ -779,7 +777,6 @@ DockIconMenu.prototype = {
         this._source = source;
 
         this.connect('activate', Lang.bind(this, this._onActivate));
-        this.connect('open-state-changed', Lang.bind(this, this._onOpenStateChanged));
 
         this.actor.add_style_class_name('dock-menu');
 
@@ -865,4 +862,4 @@ function enable() {
 function disable() {
     dock.destroy();
     dock = null;
-}
\ No newline at end of file
+}
