@@ -44,9 +44,8 @@ function injectToFunction(parent, name, func) {
         return ret;
     }
 }
+const WORKSPACE_BORDER_GAP = 10;                                    // gap between the workspace area and the workspace selector
 
-
- 
 function Rect(x, y, width, height) {
     [this.x, this.y, this.width, this.height] = arguments;
 }
@@ -106,20 +105,31 @@ Rect.prototype = {
     }
 };
 
+let winInjections, workspaceInjections, connectedSignals;
+
+function resetState() {
+    winInjections = { };
+    workspaceInjections = { };
+    workViewInjections = { };
+    connectedSignals = [ ];
+}
+
+function enable() {
+    resetState();
 
-// Put your extension initialization code here
-function main() {
     let settings = new Gio.Settings({ schema: 'org.gnome.shell.extensions.native-window-placement' });
     let placementStrategy = settings.get_enum('strategy');
-    settings.connect('changed::strategy', function() {
+    let signalId = settings.connect('changed::strategy', function() {
         placementStrategy = settings.get_enum('strategy');
         // we don't update immediately, we wait for a relayout
         // (and hope for the best)
     });
+    connectedSignals.push({ obj: settings, id: signalId });
     let useMoreScreen = settings.get_boolean('use-more-screen');
-    settings.connect('changed::use-more-screen', function() {
+    signalId = settings.connect('changed::use-more-screen', function() {
         useMoreScreen = settings.get_boolean('use-more-screen');
     });
+    connectedSignals.push({ obj: settings, id: signalId });
 
     /**
      * _calculateWindowTransformationsNatural:
@@ -137,8 +147,10 @@ function main() {
             return win2.metaWindow.get_stable_sequence() - win1.metaWindow.get_stable_sequence();
         });
 
-        // 2 * 10 px gaps at the border
-        let area = new Rect(this._x + 10, this._y + 10, this._width - 20, this._height - 20);
+        // Put a gap on the right edge of the workspace to separe it from the workspace selector
+        let x_gap = WORKSPACE_BORDER_GAP;
+        let y_gap = WORKSPACE_BORDER_GAP * this._height / this._width
+        let area = new Rect(this._x, this._y, this._width - x_gap, this._height - y_gap);
 
         let bounds = area.copy();
 
@@ -254,16 +266,14 @@ function main() {
         } while (overlap && loop_counter < WINDOW_PLACEMENT_NATURAL_MAX_TRANSLATIONS);
 
         // Work out scaling by getting the most top-left and most bottom-right window coords.
-        // The 20's and 10's are so that the windows don't touch the edge of the screen.
-        // Most 20's and 10's are already calculated into area now.
         let scale;
         scale = Math.min(area.width / bounds.width,
                          area.height / bounds.height,
                          1.0);
 
         // Make bounding rect fill the screen size for later steps
-        bounds.x = bounds.x - (area.width - bounds.width * scale) / 2 - 10 / scale;
-        bounds.y = bounds.y - (area.height - bounds.height * scale) / 2 - 10 / scale;
+        bounds.x = bounds.x - (area.width - bounds.width * scale) / 2;
+        bounds.y = bounds.y - (area.height - bounds.height * scale) / 2;
         bounds.width = area.width / scale;
         bounds.height = area.height / scale;
 
@@ -289,7 +299,8 @@ function main() {
         }
 
         return [clones, targets];
-    },
+    }
+    workspaceInjections['_calculateWindowTransformationsNatural'] = undefined;
 
     /**
      * _calculateWindowTransformationsGrid:
@@ -308,6 +319,7 @@ function main() {
 
         return [clones, targets];
     }
+    workspaceInjections['_calculateWindowTransformationsGrid'] = undefined;
 
     /**
      * positionWindows:
@@ -315,6 +327,7 @@ function main() {
      *  INITIAL - this is the initial positioning of the windows.
      *  ANIMATE - Indicates that we need animate changing position.
      */
+    workspaceInjections['positionWindows'] = Workspace.Workspace.prototype.positionWindows;
     Workspace.Workspace.prototype.positionWindows = function(flags) {
         if (this._repositionWindowsId > 0) {
             Mainloop.source_remove(this._repositionWindowsId);
@@ -403,6 +416,7 @@ function main() {
 
     /// position window titles on top of windows in overlay ////
     if (settings.get_boolean('window-captions-on-top'))  {
+        winInjections['_init'] = Workspace.WindowOverlay.prototype._init;
 	Workspace.WindowOverlay.prototype._init = function(windowClone, parentActor) {
             let metaWindow = windowClone.metaWindow;
 
@@ -450,11 +464,13 @@ function main() {
 		this._onStyleChanged();
 	},
 
+        winInjections['chromeHeights'] = Workspace.WindowOverlay.prototype.chromeHeights;
 	Workspace.WindowOverlay.prototype.chromeHeights = function () {
             return [Math.max( this.closeButton.height - this.closeButton._overlap, this.title.height - this.title._overlap),
 		    0];
 	},
 
+        winInjections['updatePositions'] = Workspace.WindowOverlay.prototype.updatePositions;
 	Workspace.WindowOverlay.prototype.updatePositions = function(cloneX, cloneY, cloneWidth, cloneHeight) {
             let button = this.closeButton;
             let title = this.title;
@@ -477,6 +493,7 @@ function main() {
             title.set_position(Math.floor(titleX), Math.floor(titleY));
 	},
 
+        winInjections['_onStyleChanged'] = Workspace.WindowOverlay.prototype._onStyleChanged;
 	Workspace.WindowOverlay.prototype._onStyleChanged = function() {
             let titleNode = this.title.get_theme_node();
             this.title._spacing = titleNode.get_length('-shell-caption-spacing');
@@ -490,4 +507,26 @@ function main() {
     }
 }
 
+function removeInjection(object, injection, name) {
+    if (injection[name] === undefined)
+        delete object[name];
+    else
+        object[name] = injection[name];
+}
 
+function disable() {
+    for (i in workspaceInjections)
+        removeInjection(Workspace.Workspace.prototype, workspaceInjections, i);
+    for (i in winInjections)
+        removeInjection(Workspace.WindowOverlay.prototype, winInjections, i);
+
+    for each (i in connectedSignals)
+        i.obj.disconnect(i.id);
+
+    global.stage.queue_relayout();
+    resetState();
+}
+
+function init() {
+    /* do nothing */
+}
\ No newline at end of file
