@@ -113,9 +113,17 @@ PlacesMenu.prototype = {
 };
 
 
-function main(metadata) {
+function init(metadata) {
     imports.gettext.bindtextdomain('gnome-shell-extensions', metadata.localedir);
+}
 
-    Panel.STANDARD_TRAY_ICON_ORDER.unshift('places-menu');
-    Panel.STANDARD_TRAY_ICON_SHELL_IMPLEMENTATION['places-menu'] = PlacesMenu;
+let _indicator;
+
+function enable() {
+    _indicator = new PlacesMenu;
+    Main.panel.addToStatusArea('places-menu', _indicator);
+}
+
+function disable() {
+    _indicator.destroy();
 }
